import * as C from './convert.js';
import { Bytes, Data, Json } from './types.js';
type BufferLike = bigint | boolean | number | string | Uint8Array;
export declare const Hex: {
    encode: (x: Uint8Array) => string;
    decode: (x: string) => Uint8Array;
    normalize: (x: Bytes) => Uint8Array;
};
export declare const Txt: {
    encode: (x: Uint8Array) => string;
    decode: (x: string) => Uint8Array;
    serialzie: (x: Data) => Uint8Array;
    revitalize: (x: Data) => Json;
};
export declare const Base64: {
    encode: (x: Uint8Array) => string;
    decode: (x: string) => Uint8Array;
    encodeUrl: (x: Uint8Array) => string;
    decodeUrl: (x: string) => Uint8Array;
};
export declare class Buff extends Uint8Array {
    static num: (number: number, size?: number | null, orient?: 'le' | 'be') => Buff;
    static big: (number: bigint, size?: number | null, orient?: 'le' | 'be') => Buff;
    static b58check(x: string): Promise<Buff>;
    static buff: (x: BufferLike, s?: number) => Buff;
    static raw: (x: ArrayBufferLike, s?: number) => Buff;
    static str: (x: string, s?: number) => Buff;
    static hex: (x: string, s?: number) => Buff;
    static json: (x: Json) => Buff;
    static base64: (x: string) => Buff;
    static b64url: (x: string) => Buff;
    static bech32: (x: string, ver?: number) => Buff;
    constructor(data: ArrayBufferLike, size?: number | null, orient?: 'le' | 'be');
    get num(): number;
    get big(): bigint;
    get arr(): number[];
    get str(): string;
    get hex(): string;
    get raw(): Uint8Array;
    get hash(): Promise<Uint8Array>;
    get id(): Promise<string>;
    toNum(orient?: 'le' | 'be'): number;
    toBig(orient?: 'le' | 'be'): bigint;
    toHash(): Promise<Uint8Array>;
    toBase58(): Promise<string>;
    toArr(): number[];
    toStr(): string;
    toHex(): string;
    toJson(): Json;
    toBytes(): Uint8Array;
    toB64url(): string;
    toBase64(padding?: boolean): string;
    toBech32(hrp: string, ver?: number): string;
    prepend(data: Uint8Array): Buff;
    append(data: Uint8Array): Buff;
    slice(start?: number, end?: number): Buff;
    reverse(): Buff;
    write(bytes: Uint8Array, offset?: number): void;
    prependVarint(num?: number): Buff;
    static from(data: Uint8Array | number[]): Buff;
    static of(...args: number[]): Buff;
    static join(arr: Uint8Array[]): Buff;
    static readVarint(num: number): Buff;
    static random(size?: number): Buff;
    static encode: typeof C.strToBytes;
    static decode: typeof C.bytesToStr;
    static normalize(data: Bytes, size?: number): Uint8Array;
    static serialize(data: Data): Uint8Array;
    static revitalize(data: Data): Json;
}
export {};
//# sourceMappingURL=buff.d.ts.map